@@ -3,9 +3,9 @@ package com.sun.tools.javac.resources;
 public final class version extends java.util.ListResourceBundle {
     protected final Object[][] getContents() {
         return new Object[][] {
-            { "full", "17.0.4+8" },
-            { "jdk", "17.0.4" },
-            { "release", "17.0.4" },
+            { "full", "17.0.4.1+1" },
+            { "jdk", "17.0.4.1" },
+            { "release", "17.0.4.1" },
         };
     }
 }
